"""
[repostats.py]
Repostats Plugin

[Author]
Shreyansh Sancheti

[About]
Gets the number of forks and stars for a given repo

[Commands]
>>> .repostats url
returns starcount stars | forkcount forks
"""


from urllib.parse import urlparse

import bs4 as bs
import requests


class Plugin:
    def __init__(self):
        pass

    def repostats(self, url):
        try:
            source = requests.get(url).text
            soup = bs.BeautifulSoup(source, "lxml")
            u = urlparse(url).path
            username = u.rpartition("/")[0]
            username = username.replace("/", "")
            reponame = u.rpartition("/")[2]
            hstar = "/" + username + "/" + reponame + "/stargazers"
            hfork = "/" + username + "/" + reponame + "/network/members"
            star = int(soup.find("a", href=hstar).get_text())
            fork = int(soup.find("a", href=hfork).get_text())
            return star + "stars |" + fork + "forks"
        except Exception:
            return "Repo doesn't exist"

    def run(self, incoming, methods, info, bot_info):
        try:
            msgs = info["args"][1:][0].split()
            print(len(msgs))
            if info["command"] == "PRIVMSG" and msgs[0] == ".repostats":
                url = int(msgs[1])
                methods["send"](info["address"], Plugin.repostats(self, url))
        except Exception as e:
            print("woops plugin error: ", e)



import importlib
import json
import os

BASE_DIR = "plugins/downloaded"
STORE_DIR = "../../honeybot-store"  # ...

plugins = {"plugins": []}
dirs = [d for d in os.listdir(BASE_DIR) if not d.startswith("__")]


def pinfo(folder, attrib):
    try:
        mod = importlib.import_module(f"plugins.downloaded.{folder}.info")
        return getattr(mod, attrib)
    except Exception as e:
        if attrib == "ORIGINAL_AUTHORS":
            return []
        else:
            return ""

    for d in dirs:
        NAME = pinfo(d, "NAME")
        ABOUT = pinfo(d, "ABOUT")
        ORIGINAL_AUTHORS = pinfo(d, "ORIGINAL_AUTHORS")
        COMMANDS = pinfo(d, "COMMANDS")
        WEBSITE = pinfo(d, "WEBSITE")
        plugins["plugins"].append(
            {
                "NAME": NAME,
                "ABOUT": ABOUT,
                "ORIGINAL_AUTHORS": ORIGINAL_AUTHORS,
                "COMMANDS": COMMANDS,
                "WEBSITE": WEBSITE,
                "FOLDER_NAME": d,
            }
        )

    print(plugins)

    with open(os.path.join(STORE_DIR, "plugins.json"), "w+") as f:
        json.dump(plugins, f, indent=4)



"""
[transfer-rumour.py]
Transfer Rumour Plugin

[Author]
Angelo Giacco

[About]
Collects transfer rumours from BBC sport

[Commands]
>>> .transfer-rumour
prints the top transfer rumour
"""
import requests
from bs4 import BeautifulSoup


class Plugin:
    def __init__(self):
        pass

    def collect_rumour(methods, info):
        r = requests.get("https://www.bbc.co.uk/sport/football/gossip")
        soup = BeautifulSoup(r.content, features="html5lib")
        content = soup.find("div", attrs={"class": "story-body"})

        for rumour in content.findAll("p"):
            for anchor in rumour.findAll("a"):
                anchor.decompose()
            try:
                if len(rumour.text) > 0:
                    methods["send"](info["address"], rumour.text)
            except TypeError:
                continue

    def run(self, incoming, methods, info, bot_info):

        try:
            if info["command"] == "PRIVMSG" and info["args"][1] == ".transfer-rumour":
                methods["send"](info["address"], Plugin.collect_rumour(methods, info))
        except Exception as e:
            print("woops plug", e)



NAME = "transfer-rumour.py"
ORIGINAL_AUTHORS = ["Angelo Giacco"]

ABOUT = """
Collects transfer rumours from BBC sport
"""

COMMANDS = """
>>> .transfer-rumour
prints the top transfer rumour
"""

WEBSITE = ""



"""
[joke.py]
Joke Plugin

[Author]
Abdur-Rahmaan Janhangeer, pythonmembers.club

[About]
sends a random joke on request

[Commands]
>>> .joke
returns a random joke
"""
import random


class Plugin:
    def __init__(self):
        pass

    def joke(self):
        jokes = [
            "Why did the physics teacher break up with the biology teacher? There was no    "
            " chemistry.",
            "I asked my daughter if she’d seen my newspaper. She told me that newspapers     are"
            " old school.She said that people use tablets nowadays and handed me her     iPad. The"
            " fly didn’t stand a chance",
            "A recent scientific study showed that out of 2,293,618,367 people, 94% are     too"
            " lazy to actually read that number.",
            "Why is it a bad idea to insult an octopus? because it is well armed",
            'Two cannibals are eating a clown, one looks to the other and asks "Does this     taste'
            ' funny to you?"',
            "What is red and smells like blue paint? Red Paint.",
            "How many South Americans does it take to change a lightbulb? A Brazilian!",
            "I have just invented a new word. Plagiarism.",
            "Why should you never trust an atom? Because they make up everything.",
            "What is brown and sticky? A stick!",
            "I tried to take a bite out of the fog, but I mist.",
            "What did the bodybuilder say when he ran out of protein powder? No whey.",
            "What do you call a fake noodle? An Impasta.",
            "Did you hear about the restaurant on the moon?"
            + " It had great food but no atmosphere.",
            "Why do the put fences around grave yards?" + " Because people are dying to get in.",
            "How do you organize a party on Mars? You planet.",
            "Why do crabs never give to charity? Because they are shellfish.",
            "What is the difference between an African and Indian Elephant?" + " About 5000 miles.",
            "I don't like to play soccer for money. I play it just for kicks.",
            "How many apples grow on a tree? All of them!",
            "Did you hear the rumor about the butter?" + " Well, I'm not going to spread it...",
            "How does a penguin build his home? Igloos it together!",
            "How to make a tissue dance? Put a little boogie in it!",
            "If you saw a robbery at the Apple store, would you be an iWitness?",
            "Why did the blind man turn down the job? He couldn't see himself doing it.",
            "Want to hear a joke about construction? We're still working on it.",
            "As I handed my dad his 50th birthday card, he looked at me with tears in his     eyes"
            ' and said, "You know, one would have been enough."',
            'I caught my wife yelling at the TV saying, "Don\'t go into the church you idiot!",    '
            " She was watching our wedding video again.",
            "When a woman is giving birth, she is literally kidding.",
            "My wife yelled at me agai for having no sense of direction."
            + " So I packed up my stuff and right.",
            'My son asked, "Can I have a book mark?" and I burst into tears.'
            + " 11 years old and he still doesn't know my name in Brian.",
            "If a child refuses to sleep during nap time,"
            + " are they guilty of resisting a rest?",
            "Geology rocks, but Geography is where it's at.",
            "Scientists were starting to get bored watching the Earth turn,"
            + " and so after 24 hours, they called it a day.",
            "My wife yelled at me an said, \"You haven't listened to anything I've said!\", which  "
            "   I thought was an interesting way to start a conversation.",
            "I’d tell you a Fibonacci joke, but’s it’s probably as bad"
            + " as the last two you’ve heard combined.",
            "What did the pirate say on his 80th birthday? AYE MATEY.",
            "It's hard to explain puns to kleptomaniacs"
            + " because they always take things literally.",
        ]

        return f"{random.choice(jokes)}"

    def run(self, incoming, methods, info, bot_info):
        try:
            # if '!~' in info['prefix']:
            # print(info)
            msgs = info["args"][1:]
            if info["command"] == "PRIVMSG" and msgs[0] == ".joke":
                methods["send"](info["address"], Plugin.joke(self))
        except Exception as e:
            print("woops plug", e)



"""
[dadjoke.py]
Dad joke plugin

[Author]
moffetma Oregon State University CS

[About]
Sends a random "dad joke" from icanhazdadjoke.com

[Commands]
>>> .dadjoke
Have you heard of the band 1023MB? They haven't got a gig yet.
"""


import requests


class Plugin:
    def __init__(self):
        pass

    def dadjoke(self):
        headers = {"Accept": "application/json"}
        r = requests.get("https://icanhazdadjoke.com", headers=headers)
        j = r.json()
        joke = j["joke"]
        return joke

    def run(self, incoming, methods, info, bot_info):
        try:
            if info["command"] == "PRIVMSG" and info["args"][1] == ".dadjoke":
                methods["send"](info["address"], Plugin.dadjoke(self))
        except Exception as e:
            print("woops dadjoke plugin error", e)



NAME = "repostats.py"
ORIGINAL_AUTHORS = ["Shreyansh Sancheti"]

ABOUT = """
Gets the number of forks and stars for a given repo
"""

COMMANDS = """
>>> .repostats url
returns starcount stars | forkcount forks
"""

WEBSITE = ""



"""
[roll.py]
Dice_Roll Plugin

[Author]
Glenn Toms

[About]
Will roll dice in the form of 1d4, 10d6 and return total.

[Commands]
>>> .roll <<dice>>
returns Total of dice
"""

try:
    import random
except ImportError:
    print("No module named 'random' found")


class Plugin:
    def __init__(self):
        pass

    def run(self, incoming, methods, info, bot_info):
        try:
            try:
                msgs = info["args"][1:][0].split()
            except Exception as e:
                pass

            if info["command"] == "PRIVMSG" and msgs[0] == ".roll":
                text = ""
                total = 0
                dice = msgs[1:][0].split("d")
                num_of_die = int(dice[0])
                dice_sides = int(dice[1])
                if num_of_die < 1 or dice_sides < 1:
                    return methods["send"](info["address"], "Can't Roll Negatives")

                if num_of_die > 1000 or dice_sides > 1000:
                    return methods["send"](info["address"], "I'm not rolling that much")

                for n in range(0, num_of_die):
                    rand = random.randint(1, dice_sides)
                    total += rand
                    text += "".join(f"Dice {n + 1}: {rand}")

                    if num_of_die == 1:
                        return methods["send"](info["address"], text)
                    else:
                        text += "".join(" / ")

                text += "".join(f"TOTAL: {total}")
                if num_of_die < 10:
                    return methods["send"](info["address"], text)
                else:
                    return methods["send"](info["address"], f"TOTAL: {total}")
        except Exception as e:
            print("woops plug", e)



"""
[anime.py]
Anime Plugin

[Author]
Christos Kontos

[About]
This plugin provides detailed information about anime from the top 100 list.
Users can query anime based on rank to get information like name, score, release date, and ranking.

[Commands]
>>> .anime rank <<ranking>> <<info_type>>
Returns the anime information based on rank (1 to 100) and the requested info type (name, score, release_date, ranking).
>>> .anime rank <<ranking>> all
Returns all details (name, score, release date, and ranking) of the anime at the specified rank.
"""

top_anime_data = [
    {'title': 'Sousou no Frieren', 'score': 9.33, 'aired': {'from': 'Sep 2023'}},
    {'title': 'Fullmetal Alchemist: Brotherhood', 'score': 9.09, 'aired': {'from': 'Apr 2009'}},
    {'title': 'Steins;Gate', 'score': 9.07, 'aired': {'from': 'Apr 2011'}},
    {'title': 'Gintama°', 'score': 9.06, 'aired': {'from': 'Apr 2015'}},
    {'title': 'Shingeki no Kyojin Season 3 Part 2', 'score': 9.05, 'aired': {'from': 'Apr 2019'}},
    {'title': 'Monogatari Series: Off & Monster Season', 'score': 9.04, 'aired': {'from': 'Jul 2024'}},
    {'title': 'Gintama: The Final', 'score': 9.04, 'aired': {'from': 'Jan 2021'}},
    {'title': "Gintama'", 'score': 9.03, 'aired': {'from': 'Apr 2011'}},
    {'title': 'Hunter x Hunter (2011)', 'score': 9.03, 'aired': {'from': 'Oct 2011'}},
    {'title': 'Ginga Eiyuu Densetsu', 'score': 9.02, 'aired': {'from': 'Jan 1988'}},
    {'title': "Gintama': Enchousen", 'score': 9.02, 'aired': {'from': 'Oct 2012'}},
    {'title': 'Bleach: Sennen Kessen-hen', 'score': 9.01, 'aired': {'from': 'Oct 2022'}},
    {'title': 'Kaguya-sama wa Kokurasetai: Ultra Romantic', 'score': 9.0, 'aired': {'from': 'Apr 2022'}},
    {'title': 'Gintama.', 'score': 8.98, 'aired': {'from': 'Jan 2017'}},
    {'title': 'Fruits Basket: The Final', 'score': 8.97, 'aired': {'from': 'Apr 2021'}},
    {'title': 'Clannad: After Story', 'score': 8.93, 'aired': {'from': 'Oct 2008'}},
    {'title': 'Gintama', 'score': 8.93, 'aired': {'from': 'Apr 2006'}},
    {'title': 'Koe no Katachi', 'score': 8.93, 'aired': {'from': 'Sep 2016'}},
    {'title': '3-gatsu no Lion 2nd Season', 'score': 8.91, 'aired': {'from': 'Oct 2017'}},
    {'title': 'Code Geass: Hangyaku no Lelouch R2', 'score': 8.91, 'aired': {'from': 'Apr 2008'}},
    {'title': 'Gintama Movie 2: Kanketsu-hen - Yorozuya yo Eien Nare', 'score': 8.9, 'aired': {'from': 'Jul 2013'}},
    {'title': 'Kusuriya no Hitorigoto', 'score': 8.89, 'aired': {'from': 'Oct 2023'}},
    {'title': 'Monster', 'score': 8.88, 'aired': {'from': 'Apr 2004'}},
    {'title': 'Shingeki no Kyojin: The Final Season - Kanketsu-hen', 'score': 8.88, 'aired': {'from': 'Mar 2023'}},
    {'title': 'Gintama.: Shirogane no Tamashii-hen - Kouhan-sen', 'score': 8.88, 'aired': {'from': 'Jul 2018'}},
    {'title': 'Owarimonogatari 2nd Season', 'score': 8.87, 'aired': {'from': 'Aug 2017'}},
    {'title': 'Violet Evergarden Movie', 'score': 8.86, 'aired': {'from': 'Sep 2020'}},
    {'title': 'Kimi no Na wa.', 'score': 8.83, 'aired': {'from': 'Aug 2016'}},
    {'title': 'Kingdom 3rd Season', 'score': 8.83, 'aired': {'from': 'Apr 2020'}},
    {'title': 'Gintama.: Shirogane no Tamashii-hen', 'score': 8.81, 'aired': {'from': 'Jan 2018'}},
    {'title': 'Vinland Saga Season 2', 'score': 8.81, 'aired': {'from': 'Jan 2023'}},
    {'title': 'Jujutsu Kaisen 2nd Season', 'score': 8.8, 'aired': {'from': 'Jul 2023'}},
    {'title': 'Boku no Kokoro no Yabai Yatsu 2nd Season', 'score': 8.8, 'aired': {'from': 'Jan 2024'}},
    {'title': 'Mob Psycho 100 II', 'score': 8.79, 'aired': {'from': 'Jan 2019'}},
    {'title': 'Kizumonogatari III: Reiketsu-hen', 'score': 8.78, 'aired': {'from': 'Jan 2017'}},
    {'title': 'Shingeki no Kyojin: The Final Season', 'score': 8.78, 'aired': {'from': 'Dec 2020'}},
    {'title': 'Sen to Chihiro no Kamikakushi', 'score': 8.77, 'aired': {'from': 'Jul 2001'}},
    {'title': 'Bocchi the Rock!', 'score': 8.77, 'aired': {'from': 'Oct 2022'}},
    {'title': 'Haikyuu!! Karasuno Koukou vs. Shiratorizawa Gakuen Koukou', 'score': 8.77,
     'aired': {'from': 'Oct 2016'}},
    {'title': 'Hajime no Ippo', 'score': 8.77, 'aired': {'from': 'Oct 2000'}},
    {'title': 'Shingeki no Kyojin: The Final Season Part 2', 'score': 8.76, 'aired': {'from': 'Jan 2022'}},
    {'title': 'Vinland Saga', 'score': 8.76, 'aired': {'from': 'Jul 2019'}},
    {'title': 'Kaguya-sama wa Kokurasetai: First Kiss wa Owaranai', 'score': 8.76, 'aired': {'from': 'Dec 2022'}},
    {'title': 'Monogatari Series: Second Season', 'score': 8.76, 'aired': {'from': 'Jul 2013'}},
    {'title': 'Cowboy Bebop', 'score': 8.75, 'aired': {'from': 'Apr 1998'}},
    {'title': 'The First Slam Dunk', 'score': 8.75, 'aired': {'from': 'Dec 2022'}},
    {'title': 'Kimetsu no Yaiba: Yuukaku-hen', 'score': 8.74, 'aired': {'from': 'Dec 2021'}},
    {'title': 'Kingdom 4th Season', 'score': 8.74, 'aired': {'from': 'Apr 2022'}},
    {'title': 'Look Back', 'score': 8.74, 'aired': {'from': 'Jun 2024'}},
    {'title': 'Hibike! Euphonium 3', 'score': 8.74, 'aired': {'from': 'Apr 2024'}},
    {'title': 'Ashita no Joe 2', 'score': 8.73, 'aired': {'from': 'Oct 1980'}},
    {'title': 'Shiguang Dailiren', 'score': 8.73, 'aired': {'from': 'Apr 2021'}},
    {'title': 'Kingdom 5th Season', 'score': 8.73, 'aired': {'from': 'Jan 2024'}},
    {'title': 'Mushishi Zoku Shou 2nd Season', 'score': 8.72, 'aired': {'from': 'Oct 2014'}},
    {'title': 'One Piece', 'score': 8.72, 'aired': {'from': 'Oct 1999'}},
    {'title': 'Mob Psycho 100 III', 'score': 8.71, 'aired': {'from': 'Oct 2022'}},
    {'title': '86 Part 2', 'score': 8.71, 'aired': {'from': 'Oct 2021'}},
    {'title': 'Shouwa Genroku Rakugo Shinjuu: Sukeroku Futatabi-hen', 'score': 8.71, 'aired': {'from': 'Jan 2017'}},
    {'title': 'Rurouni Kenshin: Meiji Kenkaku Romantan - Tsuioku-hen', 'score': 8.7, 'aired': {'from': 'Feb 1999'}},
    {'title': 'Bleach: Sennen Kessen-hen - Ketsubetsu-tan', 'score': 8.7, 'aired': {'from': 'Jul 2023'}},
    {'title': 'Code Geass: Hangyaku no Lelouch', 'score': 8.7, 'aired': {'from': 'Oct 2006'}},
    {'title': 'Great Teacher Onizuka', 'score': 8.69, 'aired': {'from': 'Jun 1999'}},
    {'title': 'Mushishi Zoku Shou', 'score': 8.69, 'aired': {'from': 'Apr 2014'}},
    {'title': 'Mo Dao Zu Shi: Wanjie Pian', 'score': 8.68, 'aired': {'from': 'Aug 2021'}},
    {'title': 'Violet Evergarden', 'score': 8.68, 'aired': {'from': 'Jan 2018'}},
    {'title': 'Tian Guan Cifu Er', 'score': 8.67, 'aired': {'from': 'Oct 2023'}},
    {'title': 'Hajime no Ippo: New Challenger', 'score': 8.67, 'aired': {'from': 'Jan 2009'}},
    {'title': 'Howl no Ugoku Shiro', 'score': 8.67, 'aired': {'from': 'Nov 2004'}},
    {'title': 'Haikyuu!! Movie: Gomisuteba no Kessen', 'score': 8.66, 'aired': {'from': 'Feb 2024'}},
    {'title': 'Mononoke Hime', 'score': 8.66, 'aired': {'from': 'Jul 1997'}},
    {'title': 'Odd Taxi', 'score': 8.66, 'aired': {'from': 'Apr 2021'}},
    {'title': 'Mushishi', 'score': 8.65, 'aired': {'from': 'Oct 2005'}},
    {'title': 'Mushoku Tensei: Isekai Ittara Honki Dasu Part 2', 'score': 8.65, 'aired': {'from': 'Oct 2021'}},
    {'title': "Fate/stay night Movie: Heaven's Feel - III. Spring Song", 'score': 8.65, 'aired': {'from': 'Aug 2020'}},
    {'title': 'Bungou Stray Dogs 5th Season', 'score': 8.64, 'aired': {'from': 'Jul 2023'}},
    {'title': 'Made in Abyss', 'score': 8.64, 'aired': {'from': 'Jul 2017'}},
    {'title': 'Natsume Yuujinchou Shi', 'score': 8.64, 'aired': {'from': 'Jan 2012'}},
    {'title': 'Shigatsu wa Kimi no Uso', 'score': 8.64, 'aired': {'from': 'Oct 2014'}},
    {'title': 'Shiguang Dailiren II', 'score': 8.63, 'aired': {'from': 'Jul 2023'}},
    {'title': 'Shingeki no Kyojin Season 3', 'score': 8.63, 'aired': {'from': 'Jul 2018'}},
    {'title': 'Tengen Toppa Gurren Lagann', 'score': 8.63, 'aired': {'from': 'Apr 2007'}},
    {'title': 'Kaguya-sama wa Kokurasetai? Tensai-tachi no Renai Zunousen', 'score': 8.63,
     'aired': {'from': 'Apr 2020'}},
    {'title': 'Made in Abyss: Retsujitsu no Ougonkyou', 'score': 8.62, 'aired': {'from': 'Jul 2022'}},
    {'title': 'Ping Pong the Animation', 'score': 8.62, 'aired': {'from': 'Apr 2014'}},
    {'title': '"Oshi no Ko"', 'score': 8.62, 'aired': {'from': 'Apr 2023'}},
    {'title': 'Death Note', 'score': 8.62, 'aired': {'from': 'Oct 2006'}},
    {'title': 'Haikyuu!! Second Season', 'score': 8.62, 'aired': {'from': 'Oct 2015'}},
    {'title': 'Dungeon Meshi', 'score': 8.61, 'aired': {'from': 'Jan 2024'}},
    {'title': 'Made in Abyss Movie 3: Fukaki Tamashii no Reimei', 'score': 8.61, 'aired': {'from': 'Jan 2020'}},
    {'title': 'Natsume Yuujinchou Roku', 'score': 8.61, 'aired': {'from': 'Apr 2017'}},
    {'title': 'Cyberpunk: Edgerunners', 'score': 8.6, 'aired': {'from': 'Sep 2022'}},
    {'title': 'Hajime no Ippo: Rising', 'score': 8.6, 'aired': {'from': 'Oct 2013'}},
    {'title': 'Suzumiya Haruhi no Shoushitsu', 'score': 8.6, 'aired': {'from': 'Feb 2010'}},
    {'title': 'Shin Evangelion Movie:||', 'score': 8.59, 'aired': {'from': 'Mar 2021'}},
    {'title': 'Kenpuu Denki Berserk', 'score': 8.59, 'aired': {'from': 'Oct 1997'}},
    {'title': 'Kimi ni Todoke 3rd Season', 'score': 8.59, 'aired': {'from': 'Aug 2024'}},
    {'title': 'Mushishi Zoku Shou: Suzu no Shizuku', 'score': 8.59, 'aired': {'from': 'May 2015'}},
    {'title': 'Seishun Buta Yarou wa Yumemiru Shoujo no Yume wo Minai', 'score': 8.59, 'aired': {'from': 'Jun 2019'}},
    {'title': 'JoJo no Kimyou na Bouken Part 5: Ougon no Kaze', 'score': 8.58, 'aired': {'from': 'Oct 2018'}},
    {'title': 'Jujutsu Kaisen', 'score': 8.58, 'aired': {'from': 'Oct 2020'}},
]

class Plugin:
    def __init__(self):
        self.top_anime_data = top_anime_data
        self.MAX_MESSAGE_LENGTH = 400  # Adjust this value as needed

    def __get_anime_info(self, rank, info_type):
        if rank < 1 or rank > len(self.top_anime_data):
            return f"Rank must be between 1 and {len(self.top_anime_data)}."

        try:
            anime = self.top_anime_data[rank - 1]
            title = anime["title"]
            score = anime["score"]
            release_date = anime["aired"]["from"][:10]

            if info_type == "name":
                return title
            elif info_type == "score":
                return f"Score: {score}"
            elif info_type == "release_date":
                return f"Release Date: {release_date}"
            elif info_type == "all":
                return f"Title: {title} | Score: {score} | Release Date: {release_date}"
            else:
                return "Invalid info type. Please use 'name', 'score', 'release_date', or 'all'."
        except IndexError:
            return "Anime data is not available for the given rank."

    def run(self, incoming, methods, info, bot_info):
        try:
            command_parts = info["args"][1].split()  # Split the second element (the command) by spaces

            if info["command"] == "PRIVMSG":
                if command_parts[0] == ".anime" and len(command_parts) > 2 and command_parts[1] == "rank":
                    try:
                        rank = int(command_parts[2])
                        info_type = command_parts[3] if len(command_parts) > 3 else "all"
                        anime_info = self.__get_anime_info(rank, info_type)
                        methods["send"](info["address"], anime_info)
                    except (IndexError, ValueError) as e:
                        methods["send"](info["address"], "Invalid command. Use: .anime rank <<ranking>> <<info_type>>")
        except Exception as e:
            print("Something went wrong. There is a Plugin Error: ", e)


"""
[corona.py]
Coronavirus Plugin

[Author]
Angelo Giacco

[About]
provides information about the coronavirus pandemic

[Commands]
>>> .corona
returns global coronavirus information

.corona <<country>>
returns coronavirus information for a specific country
"""
import datetime
import string

import requests
from bs4 import BeautifulSoup


class Plugin:
    def __init__(self):
        pass

    def scrape(self, country):
        response = requests.get(
            "https://www.worldometers.info/coronavirus/"
        )  # gets the coronavirus statistcs
        doc = BeautifulSoup(response.text, "html.parser")  # parses website
        cases = doc.find_all(class_="maincounter-number")
        data = doc.find_all("td")
        if country == "global":
            most_affected = []  # each element is an array as follows [country,cases,deaths]
            for index in range(0, 45, 11):
                most_affected.append(
                    [
                        str(data[index].text),
                        str(data[index + 1].text),
                        str(data[index + 3].text.strip()),
                    ]
                )
            today = str(datetime.date.today())
            msg = (
                "The latest coronavirus pandemic figures as of "
                + today
                + " show "
                + " that there are currently "
                + str(cases[0].text.strip())
                + " cases of "
                + "coronavirus of which "
                + str(cases[2].text.strip())
                + " have recovered. "
                + "Unfortunately, "
                + str(cases[1].text.strip())
                + " patients have died as a "
                + "result of the coronavirus pandemic. May they rest in peace."
            )
            msg += "The most affected countries are the following: \n"
            for c in most_affected:
                country = c[0]
                total_cases = c[1]
                deaths = c[2]
                string = (
                    country
                    + " has "
                    + total_cases
                    + " confirmed cases that have led to "
                    + deaths
                    + " deaths. RIP \n"
                )
                msg += string
            return msg
        else:
            name_confusion = {
                "United Kingdom": "UK",
                "United States": "USA",
                "Uk": "UK",
                "America": "USA",
                "Usa": "USA",
                "United States Of America": "USA",
                "South Korea": "S. Korea",
                "Czech Republic": "Czechia",
                "Faroe Islands": "Faeroe Islands",
                "United Arab Emirates": "UAE",
                "Uae": "UAE",
                "Democratic Republic Of Congo": "DRC",
                "Drc": "DRC",
                "United States Virgin Islands": "U.S. Virgin Islands",
                "Central African Republic": "CAR",
                "Car": "CAR",
            }
            if country in name_confusion:
                country = name_confusion[country]
            for index in range(0, len(data) - 11, 11):
                name = data[index].text
                if data[index].text == country:
                    today = str(datetime.date.today())
                    cases = data[index + 1].text
                    deaths = data[index + 3].text
                    recovered = data[index + 5].text
                    msg = (
                        "The latest coronavirus pandemic figures as of "
                        + today
                        + " for "
                        + name
                        + " show"
                        + " that there are currently "
                        + cases
                        + " cases of coronavirus in "
                        + name
                        + "."
                    )
                    if recovered != " ":
                        msg += " Of these " + recovered + " have recovered. "
                    else:
                        msg += " None have recovered yet. "
                    if deaths != " ":
                        msg += (
                            "Unfortunately, "
                            + deaths.strip()
                            + " patients in "
                            + name
                            + " have died as a "
                            + "result of the coronavirus pandemic. May they rest in peace."
                        )
                    else:
                        msg += (
                            "Fortunately nobody has died yet in "
                            + name
                            + " as a result of coronavirus."
                        )
                    return msg
                    break
            else:
                msg = "Invalid country input"
                return msg

    def run(self, incoming, methods, info, bot_info):
        try:
            msgs = info["args"][1:][0].split()
            if info["command"] == "PRIVMSG" and msgs[0] == ".corona":
                if len(msgs) == 1:
                    headlines = Plugin.scrape(self, "global")
                    for line in headlines.splitlines():
                        methods["send"](info["address"], line)
                else:
                    country_name = " ".join(msgs[1:])
                    country_name = string.capwords(country_name)
                    msg = Plugin.scrape(self, country_name)
                    methods["send"](info["address"], msg)

        except Exception as e:
            print("woops, corona plugin error", e)
